# coding: utf-8

"""
    The Plaid API

    The Plaid REST API. Please see https://plaid.com/docs/api for more details.  # noqa: E501
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from plaid.generated_plaid.configuration import Configuration


class LinkTokenCreateRequest(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'client_id': 'str',
        'secret': 'str',
        'client_name': 'str',
        'language': 'str',
        'country_codes': 'list[str]',
        'user': 'LinkTokenCreateRequestUser',
        'products': 'list[str]',
        'webhook': 'str',
        'access_token': 'str',
        'link_customization_name': 'str',
        'redirect_uri': 'str',
        'android_package_name': 'str',
        'account_filters': 'LinkTokenAccountFilters',
        'institution_id': 'str',
        'payment_initiation': 'LinkTokenCreateRequestPaymentInitiation'
    }

    attribute_map = {
        'client_id': 'client_id',
        'secret': 'secret',
        'client_name': 'client_name',
        'language': 'language',
        'country_codes': 'country_codes',
        'user': 'user',
        'products': 'products',
        'webhook': 'webhook',
        'access_token': 'access_token',
        'link_customization_name': 'link_customization_name',
        'redirect_uri': 'redirect_uri',
        'android_package_name': 'android_package_name',
        'account_filters': 'account_filters',
        'institution_id': 'institution_id',
        'payment_initiation': 'payment_initiation'
    }

    def __init__(self, client_id=None, secret=None, client_name=None, language=None, country_codes=None, user=None, products=None, webhook=None, access_token=None, link_customization_name=None, redirect_uri=None, android_package_name=None, account_filters=None, institution_id=None, payment_initiation=None, local_vars_configuration=None):  # noqa: E501
        """LinkTokenCreateRequest - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._client_id = None
        self._secret = None
        self._client_name = None
        self._language = None
        self._country_codes = None
        self._user = None
        self._products = None
        self._webhook = None
        self._access_token = None
        self._link_customization_name = None
        self._redirect_uri = None
        self._android_package_name = None
        self._account_filters = None
        self._institution_id = None
        self._payment_initiation = None
        self.discriminator = None

        self.client_id = client_id
        self.secret = secret
        self.client_name = client_name
        self.language = language
        self.country_codes = country_codes
        self.user = user
        if products is not None:
            self.products = products
        if webhook is not None:
            self.webhook = webhook
        if access_token is not None:
            self.access_token = access_token
        if link_customization_name is not None:
            self.link_customization_name = link_customization_name
        if redirect_uri is not None:
            self.redirect_uri = redirect_uri
        if android_package_name is not None:
            self.android_package_name = android_package_name
        if account_filters is not None:
            self.account_filters = account_filters
        if institution_id is not None:
            self.institution_id = institution_id
        if payment_initiation is not None:
            self.payment_initiation = payment_initiation

    @property
    def client_id(self):
        """Gets the client_id of this LinkTokenCreateRequest.  # noqa: E501

        Your Plaid API `client_id`.  # noqa: E501

        :return: The client_id of this LinkTokenCreateRequest.  # noqa: E501
        :rtype: str
        """
        return self._client_id

    @client_id.setter
    def client_id(self, client_id):
        """Sets the client_id of this LinkTokenCreateRequest.

        Your Plaid API `client_id`.  # noqa: E501

        :param client_id: The client_id of this LinkTokenCreateRequest.  # noqa: E501
        :type client_id: str
        """
        if self.local_vars_configuration.client_side_validation and client_id is None:  # noqa: E501
            raise ValueError("Invalid value for `client_id`, must not be `None`")  # noqa: E501

        self._client_id = client_id

    @property
    def secret(self):
        """Gets the secret of this LinkTokenCreateRequest.  # noqa: E501

        Your Plaid API `secret`.  # noqa: E501

        :return: The secret of this LinkTokenCreateRequest.  # noqa: E501
        :rtype: str
        """
        return self._secret

    @secret.setter
    def secret(self, secret):
        """Sets the secret of this LinkTokenCreateRequest.

        Your Plaid API `secret`.  # noqa: E501

        :param secret: The secret of this LinkTokenCreateRequest.  # noqa: E501
        :type secret: str
        """
        if self.local_vars_configuration.client_side_validation and secret is None:  # noqa: E501
            raise ValueError("Invalid value for `secret`, must not be `None`")  # noqa: E501

        self._secret = secret

    @property
    def client_name(self):
        """Gets the client_name of this LinkTokenCreateRequest.  # noqa: E501

        The name of your application, as it should be displayed in Link.  # noqa: E501

        :return: The client_name of this LinkTokenCreateRequest.  # noqa: E501
        :rtype: str
        """
        return self._client_name

    @client_name.setter
    def client_name(self, client_name):
        """Sets the client_name of this LinkTokenCreateRequest.

        The name of your application, as it should be displayed in Link.  # noqa: E501

        :param client_name: The client_name of this LinkTokenCreateRequest.  # noqa: E501
        :type client_name: str
        """
        if self.local_vars_configuration.client_side_validation and client_name is None:  # noqa: E501
            raise ValueError("Invalid value for `client_name`, must not be `None`")  # noqa: E501

        self._client_name = client_name

    @property
    def language(self):
        """Gets the language of this LinkTokenCreateRequest.  # noqa: E501

        The language that Link should be displayed in.  Supported languages are: - English (`'en'`) - French (`'fr'`) - Spanish (`'es'`) - Dutch (`'nl'`)  When using a Link customization, the language configured here must match the setting in the customization, or the customization will not be applied.  # noqa: E501

        :return: The language of this LinkTokenCreateRequest.  # noqa: E501
        :rtype: str
        """
        return self._language

    @language.setter
    def language(self, language):
        """Sets the language of this LinkTokenCreateRequest.

        The language that Link should be displayed in.  Supported languages are: - English (`'en'`) - French (`'fr'`) - Spanish (`'es'`) - Dutch (`'nl'`)  When using a Link customization, the language configured here must match the setting in the customization, or the customization will not be applied.  # noqa: E501

        :param language: The language of this LinkTokenCreateRequest.  # noqa: E501
        :type language: str
        """
        if self.local_vars_configuration.client_side_validation and language is None:  # noqa: E501
            raise ValueError("Invalid value for `language`, must not be `None`")  # noqa: E501

        self._language = language

    @property
    def country_codes(self):
        """Gets the country_codes of this LinkTokenCreateRequest.  # noqa: E501

        Specify an array of Plaid-supported country codes using the ISO-3166-1 alpha-2 country code standard. Note that if you initialize with a European country code, your users will see the European consent panel during the Link flow. Supported country codes are: `US`, `CA`, `ES`, `FR`, `GB`, `IE`, `NL`. Example value: `['US', 'CA']`. If Link is launched with multiple country codes, only products that you are enabled for in all countries will be used by Link.  If using a Link customization, make sure the country codes in the customization match those specified in `country_codes`. If both `country_codes` and a Link customization are used, the value in `country_codes` may override the value in the customization.  If using the optional Auth features Instant Match, Same-day Micro-deposits, or Automated Micro-deposits, `country_codes` must be set to `['US']`.  # noqa: E501

        :return: The country_codes of this LinkTokenCreateRequest.  # noqa: E501
        :rtype: list[str]
        """
        return self._country_codes

    @country_codes.setter
    def country_codes(self, country_codes):
        """Sets the country_codes of this LinkTokenCreateRequest.

        Specify an array of Plaid-supported country codes using the ISO-3166-1 alpha-2 country code standard. Note that if you initialize with a European country code, your users will see the European consent panel during the Link flow. Supported country codes are: `US`, `CA`, `ES`, `FR`, `GB`, `IE`, `NL`. Example value: `['US', 'CA']`. If Link is launched with multiple country codes, only products that you are enabled for in all countries will be used by Link.  If using a Link customization, make sure the country codes in the customization match those specified in `country_codes`. If both `country_codes` and a Link customization are used, the value in `country_codes` may override the value in the customization.  If using the optional Auth features Instant Match, Same-day Micro-deposits, or Automated Micro-deposits, `country_codes` must be set to `['US']`.  # noqa: E501

        :param country_codes: The country_codes of this LinkTokenCreateRequest.  # noqa: E501
        :type country_codes: list[str]
        """
        if self.local_vars_configuration.client_side_validation and country_codes is None:  # noqa: E501
            raise ValueError("Invalid value for `country_codes`, must not be `None`")  # noqa: E501

        self._country_codes = country_codes

    @property
    def user(self):
        """Gets the user of this LinkTokenCreateRequest.  # noqa: E501


        :return: The user of this LinkTokenCreateRequest.  # noqa: E501
        :rtype: LinkTokenCreateRequestUser
        """
        return self._user

    @user.setter
    def user(self, user):
        """Sets the user of this LinkTokenCreateRequest.


        :param user: The user of this LinkTokenCreateRequest.  # noqa: E501
        :type user: LinkTokenCreateRequestUser
        """
        if self.local_vars_configuration.client_side_validation and user is None:  # noqa: E501
            raise ValueError("Invalid value for `user`, must not be `None`")  # noqa: E501

        self._user = user

    @property
    def products(self):
        """Gets the products of this LinkTokenCreateRequest.  # noqa: E501

        List of Plaid product(s) you wish to use. If launching Link in update mode, should be omitted; required otherwise. Valid products are:  `transactions`, `auth`, `identity`, `assets`, `investments`, `liabilities`, `payment_initiation`  Example: `['auth', 'transactions']`  `balance` is *not* a valid value, the Balance product does not require explicit initalization and will automatically be initialized when any other product is initialized. Only institutions that support *all* requested products will be shown in Link.  In Production, you will be billed for each product that you specify when initializing Link. Note that a product cannot be removed from an Item once the Item has been initialized with that product. To stop billing on an Item for subscription-based products, such as Liabilities, Investments, and Transactions, remove the Item via `/item/remove`.  # noqa: E501

        :return: The products of this LinkTokenCreateRequest.  # noqa: E501
        :rtype: list[str]
        """
        return self._products

    @products.setter
    def products(self, products):
        """Sets the products of this LinkTokenCreateRequest.

        List of Plaid product(s) you wish to use. If launching Link in update mode, should be omitted; required otherwise. Valid products are:  `transactions`, `auth`, `identity`, `assets`, `investments`, `liabilities`, `payment_initiation`  Example: `['auth', 'transactions']`  `balance` is *not* a valid value, the Balance product does not require explicit initalization and will automatically be initialized when any other product is initialized. Only institutions that support *all* requested products will be shown in Link.  In Production, you will be billed for each product that you specify when initializing Link. Note that a product cannot be removed from an Item once the Item has been initialized with that product. To stop billing on an Item for subscription-based products, such as Liabilities, Investments, and Transactions, remove the Item via `/item/remove`.  # noqa: E501

        :param products: The products of this LinkTokenCreateRequest.  # noqa: E501
        :type products: list[str]
        """

        self._products = products

    @property
    def webhook(self):
        """Gets the webhook of this LinkTokenCreateRequest.  # noqa: E501

        The destination URL to which any webhooks should be sent.  # noqa: E501

        :return: The webhook of this LinkTokenCreateRequest.  # noqa: E501
        :rtype: str
        """
        return self._webhook

    @webhook.setter
    def webhook(self, webhook):
        """Sets the webhook of this LinkTokenCreateRequest.

        The destination URL to which any webhooks should be sent.  # noqa: E501

        :param webhook: The webhook of this LinkTokenCreateRequest.  # noqa: E501
        :type webhook: str
        """

        self._webhook = webhook

    @property
    def access_token(self):
        """Gets the access_token of this LinkTokenCreateRequest.  # noqa: E501

        The `access_token` associated with the Item to update, used when updating or modifying an existing `access_token`. Used when launching Link in update mode or (optionally) when initializing Link as part of the Payment Initiation (Europe) flow.  # noqa: E501

        :return: The access_token of this LinkTokenCreateRequest.  # noqa: E501
        :rtype: str
        """
        return self._access_token

    @access_token.setter
    def access_token(self, access_token):
        """Sets the access_token of this LinkTokenCreateRequest.

        The `access_token` associated with the Item to update, used when updating or modifying an existing `access_token`. Used when launching Link in update mode or (optionally) when initializing Link as part of the Payment Initiation (Europe) flow.  # noqa: E501

        :param access_token: The access_token of this LinkTokenCreateRequest.  # noqa: E501
        :type access_token: str
        """

        self._access_token = access_token

    @property
    def link_customization_name(self):
        """Gets the link_customization_name of this LinkTokenCreateRequest.  # noqa: E501

        The name of the Link customization from the Plaid Dashboard to be applied to Link. If not specified, the `default` customization will be used. When using a Link customization, the language in the customization must match the language selected via the `language` parameter, and the countries in the customization should match the country codes selected via `country_codes`.  # noqa: E501

        :return: The link_customization_name of this LinkTokenCreateRequest.  # noqa: E501
        :rtype: str
        """
        return self._link_customization_name

    @link_customization_name.setter
    def link_customization_name(self, link_customization_name):
        """Sets the link_customization_name of this LinkTokenCreateRequest.

        The name of the Link customization from the Plaid Dashboard to be applied to Link. If not specified, the `default` customization will be used. When using a Link customization, the language in the customization must match the language selected via the `language` parameter, and the countries in the customization should match the country codes selected via `country_codes`.  # noqa: E501

        :param link_customization_name: The link_customization_name of this LinkTokenCreateRequest.  # noqa: E501
        :type link_customization_name: str
        """

        self._link_customization_name = link_customization_name

    @property
    def redirect_uri(self):
        """Gets the redirect_uri of this LinkTokenCreateRequest.  # noqa: E501

        A URI indicating the destination where a user should be forwarded after completing the Link flow; used to support OAuth authentication flows when launching Link in the browser or via a webview. The `redirect_uri` should not contain any query parameters. If `android_package_name` is specified, this field should be left blank. For iOS integrations, `redirect_uri` should be left blank and the client-side `oauthRedirectUri` parameter should be used instead. Any redirect URI specified here must also be added under the \"Allowed redirect URIs\" configuration on the [developer dashboard](https://dashboard.plaid.com/team/api). In non-Sandbox (Production and Development) environments, the `redirect_uri` must begin with https.  # noqa: E501

        :return: The redirect_uri of this LinkTokenCreateRequest.  # noqa: E501
        :rtype: str
        """
        return self._redirect_uri

    @redirect_uri.setter
    def redirect_uri(self, redirect_uri):
        """Sets the redirect_uri of this LinkTokenCreateRequest.

        A URI indicating the destination where a user should be forwarded after completing the Link flow; used to support OAuth authentication flows when launching Link in the browser or via a webview. The `redirect_uri` should not contain any query parameters. If `android_package_name` is specified, this field should be left blank. For iOS integrations, `redirect_uri` should be left blank and the client-side `oauthRedirectUri` parameter should be used instead. Any redirect URI specified here must also be added under the \"Allowed redirect URIs\" configuration on the [developer dashboard](https://dashboard.plaid.com/team/api). In non-Sandbox (Production and Development) environments, the `redirect_uri` must begin with https.  # noqa: E501

        :param redirect_uri: The redirect_uri of this LinkTokenCreateRequest.  # noqa: E501
        :type redirect_uri: str
        """

        self._redirect_uri = redirect_uri

    @property
    def android_package_name(self):
        """Gets the android_package_name of this LinkTokenCreateRequest.  # noqa: E501

        The name of your app's Android package. Required if using the `link_token` to initialize Link on Android. When creating a `link_token` for initializing Link on other platforms, this field must be left blank. Any package name specified here must also be added to the Allowed Android package names setting on the [developer dashboard](https://dashboard.plaid.com/team/api).   # noqa: E501

        :return: The android_package_name of this LinkTokenCreateRequest.  # noqa: E501
        :rtype: str
        """
        return self._android_package_name

    @android_package_name.setter
    def android_package_name(self, android_package_name):
        """Sets the android_package_name of this LinkTokenCreateRequest.

        The name of your app's Android package. Required if using the `link_token` to initialize Link on Android. When creating a `link_token` for initializing Link on other platforms, this field must be left blank. Any package name specified here must also be added to the Allowed Android package names setting on the [developer dashboard](https://dashboard.plaid.com/team/api).   # noqa: E501

        :param android_package_name: The android_package_name of this LinkTokenCreateRequest.  # noqa: E501
        :type android_package_name: str
        """

        self._android_package_name = android_package_name

    @property
    def account_filters(self):
        """Gets the account_filters of this LinkTokenCreateRequest.  # noqa: E501


        :return: The account_filters of this LinkTokenCreateRequest.  # noqa: E501
        :rtype: LinkTokenAccountFilters
        """
        return self._account_filters

    @account_filters.setter
    def account_filters(self, account_filters):
        """Sets the account_filters of this LinkTokenCreateRequest.


        :param account_filters: The account_filters of this LinkTokenCreateRequest.  # noqa: E501
        :type account_filters: LinkTokenAccountFilters
        """

        self._account_filters = account_filters

    @property
    def institution_id(self):
        """Gets the institution_id of this LinkTokenCreateRequest.  # noqa: E501

        Used for certain legacy use cases  # noqa: E501

        :return: The institution_id of this LinkTokenCreateRequest.  # noqa: E501
        :rtype: str
        """
        return self._institution_id

    @institution_id.setter
    def institution_id(self, institution_id):
        """Sets the institution_id of this LinkTokenCreateRequest.

        Used for certain legacy use cases  # noqa: E501

        :param institution_id: The institution_id of this LinkTokenCreateRequest.  # noqa: E501
        :type institution_id: str
        """

        self._institution_id = institution_id

    @property
    def payment_initiation(self):
        """Gets the payment_initiation of this LinkTokenCreateRequest.  # noqa: E501


        :return: The payment_initiation of this LinkTokenCreateRequest.  # noqa: E501
        :rtype: LinkTokenCreateRequestPaymentInitiation
        """
        return self._payment_initiation

    @payment_initiation.setter
    def payment_initiation(self, payment_initiation):
        """Sets the payment_initiation of this LinkTokenCreateRequest.


        :param payment_initiation: The payment_initiation of this LinkTokenCreateRequest.  # noqa: E501
        :type payment_initiation: LinkTokenCreateRequestPaymentInitiation
        """

        self._payment_initiation = payment_initiation

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, LinkTokenCreateRequest):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, LinkTokenCreateRequest):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    The Plaid API

    The Plaid REST API. Please see https://plaid.com/docs/api for more details.  # noqa: E501
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from plaid.generated_plaid.configuration import Configuration


class CreditCardLiability(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'account_id': 'str',
        'aprs': 'list[APR]',
        'is_overdue': 'bool',
        'last_payment_amount': 'float',
        'last_payment_date': 'str',
        'last_statement_balance': 'float',
        'last_statement_issue_date': 'str',
        'minimum_payment_amount': 'float',
        'next_payment_due_date': 'str'
    }

    attribute_map = {
        'account_id': 'account_id',
        'aprs': 'aprs',
        'is_overdue': 'is_overdue',
        'last_payment_amount': 'last_payment_amount',
        'last_payment_date': 'last_payment_date',
        'last_statement_balance': 'last_statement_balance',
        'last_statement_issue_date': 'last_statement_issue_date',
        'minimum_payment_amount': 'minimum_payment_amount',
        'next_payment_due_date': 'next_payment_due_date'
    }

    def __init__(self, account_id=None, aprs=None, is_overdue=None, last_payment_amount=None, last_payment_date=None, last_statement_balance=None, last_statement_issue_date=None, minimum_payment_amount=None, next_payment_due_date=None, local_vars_configuration=None):  # noqa: E501
        """CreditCardLiability - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._account_id = None
        self._aprs = None
        self._is_overdue = None
        self._last_payment_amount = None
        self._last_payment_date = None
        self._last_statement_balance = None
        self._last_statement_issue_date = None
        self._minimum_payment_amount = None
        self._next_payment_due_date = None
        self.discriminator = None

        self.account_id = account_id
        if aprs is not None:
            self.aprs = aprs
        self.is_overdue = is_overdue
        if last_payment_amount is not None:
            self.last_payment_amount = last_payment_amount
        if last_payment_date is not None:
            self.last_payment_date = last_payment_date
        if last_statement_balance is not None:
            self.last_statement_balance = last_statement_balance
        if last_statement_issue_date is not None:
            self.last_statement_issue_date = last_statement_issue_date
        if minimum_payment_amount is not None:
            self.minimum_payment_amount = minimum_payment_amount
        if next_payment_due_date is not None:
            self.next_payment_due_date = next_payment_due_date

    @property
    def account_id(self):
        """Gets the account_id of this CreditCardLiability.  # noqa: E501

        The ID of the account that this liability belongs to.  # noqa: E501

        :return: The account_id of this CreditCardLiability.  # noqa: E501
        :rtype: str
        """
        return self._account_id

    @account_id.setter
    def account_id(self, account_id):
        """Sets the account_id of this CreditCardLiability.

        The ID of the account that this liability belongs to.  # noqa: E501

        :param account_id: The account_id of this CreditCardLiability.  # noqa: E501
        :type account_id: str
        """

        self._account_id = account_id

    @property
    def aprs(self):
        """Gets the aprs of this CreditCardLiability.  # noqa: E501

        The various interest rates that apply to the account.  # noqa: E501

        :return: The aprs of this CreditCardLiability.  # noqa: E501
        :rtype: list[APR]
        """
        return self._aprs

    @aprs.setter
    def aprs(self, aprs):
        """Sets the aprs of this CreditCardLiability.

        The various interest rates that apply to the account.  # noqa: E501

        :param aprs: The aprs of this CreditCardLiability.  # noqa: E501
        :type aprs: list[APR]
        """

        self._aprs = aprs

    @property
    def is_overdue(self):
        """Gets the is_overdue of this CreditCardLiability.  # noqa: E501

        true if a payment is currently overdue. Availability for this field is limited.  # noqa: E501

        :return: The is_overdue of this CreditCardLiability.  # noqa: E501
        :rtype: bool
        """
        return self._is_overdue

    @is_overdue.setter
    def is_overdue(self, is_overdue):
        """Sets the is_overdue of this CreditCardLiability.

        true if a payment is currently overdue. Availability for this field is limited.  # noqa: E501

        :param is_overdue: The is_overdue of this CreditCardLiability.  # noqa: E501
        :type is_overdue: bool
        """

        self._is_overdue = is_overdue

    @property
    def last_payment_amount(self):
        """Gets the last_payment_amount of this CreditCardLiability.  # noqa: E501

        The amount of the last payment.  # noqa: E501

        :return: The last_payment_amount of this CreditCardLiability.  # noqa: E501
        :rtype: float
        """
        return self._last_payment_amount

    @last_payment_amount.setter
    def last_payment_amount(self, last_payment_amount):
        """Sets the last_payment_amount of this CreditCardLiability.

        The amount of the last payment.  # noqa: E501

        :param last_payment_amount: The last_payment_amount of this CreditCardLiability.  # noqa: E501
        :type last_payment_amount: float
        """

        self._last_payment_amount = last_payment_amount

    @property
    def last_payment_date(self):
        """Gets the last_payment_date of this CreditCardLiability.  # noqa: E501

        The date of the last payment. Dates are returned in an ISO 8601 format (YYYY-MM-DD). Availability for this field is limited.  # noqa: E501

        :return: The last_payment_date of this CreditCardLiability.  # noqa: E501
        :rtype: str
        """
        return self._last_payment_date

    @last_payment_date.setter
    def last_payment_date(self, last_payment_date):
        """Sets the last_payment_date of this CreditCardLiability.

        The date of the last payment. Dates are returned in an ISO 8601 format (YYYY-MM-DD). Availability for this field is limited.  # noqa: E501

        :param last_payment_date: The last_payment_date of this CreditCardLiability.  # noqa: E501
        :type last_payment_date: str
        """

        self._last_payment_date = last_payment_date

    @property
    def last_statement_balance(self):
        """Gets the last_statement_balance of this CreditCardLiability.  # noqa: E501

        The outstanding balance on the last statement. Availability for this field is limited.  # noqa: E501

        :return: The last_statement_balance of this CreditCardLiability.  # noqa: E501
        :rtype: float
        """
        return self._last_statement_balance

    @last_statement_balance.setter
    def last_statement_balance(self, last_statement_balance):
        """Sets the last_statement_balance of this CreditCardLiability.

        The outstanding balance on the last statement. Availability for this field is limited.  # noqa: E501

        :param last_statement_balance: The last_statement_balance of this CreditCardLiability.  # noqa: E501
        :type last_statement_balance: float
        """

        self._last_statement_balance = last_statement_balance

    @property
    def last_statement_issue_date(self):
        """Gets the last_statement_issue_date of this CreditCardLiability.  # noqa: E501

        The date of the last statement. Dates are returned in an ISO 8601 format (YYYY-MM-DD).  # noqa: E501

        :return: The last_statement_issue_date of this CreditCardLiability.  # noqa: E501
        :rtype: str
        """
        return self._last_statement_issue_date

    @last_statement_issue_date.setter
    def last_statement_issue_date(self, last_statement_issue_date):
        """Sets the last_statement_issue_date of this CreditCardLiability.

        The date of the last statement. Dates are returned in an ISO 8601 format (YYYY-MM-DD).  # noqa: E501

        :param last_statement_issue_date: The last_statement_issue_date of this CreditCardLiability.  # noqa: E501
        :type last_statement_issue_date: str
        """

        self._last_statement_issue_date = last_statement_issue_date

    @property
    def minimum_payment_amount(self):
        """Gets the minimum_payment_amount of this CreditCardLiability.  # noqa: E501

        The minimum payment due for the next billing cycle.  # noqa: E501

        :return: The minimum_payment_amount of this CreditCardLiability.  # noqa: E501
        :rtype: float
        """
        return self._minimum_payment_amount

    @minimum_payment_amount.setter
    def minimum_payment_amount(self, minimum_payment_amount):
        """Sets the minimum_payment_amount of this CreditCardLiability.

        The minimum payment due for the next billing cycle.  # noqa: E501

        :param minimum_payment_amount: The minimum_payment_amount of this CreditCardLiability.  # noqa: E501
        :type minimum_payment_amount: float
        """

        self._minimum_payment_amount = minimum_payment_amount

    @property
    def next_payment_due_date(self):
        """Gets the next_payment_due_date of this CreditCardLiability.  # noqa: E501

        The due date for the next payment. The due date is `null` if a payment is not expected. Dates are returned in an ISO 8601 format (YYYY-MM-DD).  # noqa: E501

        :return: The next_payment_due_date of this CreditCardLiability.  # noqa: E501
        :rtype: str
        """
        return self._next_payment_due_date

    @next_payment_due_date.setter
    def next_payment_due_date(self, next_payment_due_date):
        """Sets the next_payment_due_date of this CreditCardLiability.

        The due date for the next payment. The due date is `null` if a payment is not expected. Dates are returned in an ISO 8601 format (YYYY-MM-DD).  # noqa: E501

        :param next_payment_due_date: The next_payment_due_date of this CreditCardLiability.  # noqa: E501
        :type next_payment_due_date: str
        """

        self._next_payment_due_date = next_payment_due_date

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CreditCardLiability):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, CreditCardLiability):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    The Plaid API

    The Plaid REST API. Please see https://plaid.com/docs/api for more details.  # noqa: E501
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from plaid.generated_plaid.configuration import Configuration


class AssetReportRefreshRequest(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'client_id': 'str',
        'secret': 'str',
        'asset_report_token': 'str',
        'days_requested': 'float',
        'options': 'AssetReportRefreshRequestOptions'
    }

    attribute_map = {
        'client_id': 'client_id',
        'secret': 'secret',
        'asset_report_token': 'asset_report_token',
        'days_requested': 'days_requested',
        'options': 'options'
    }

    def __init__(self, client_id=None, secret=None, asset_report_token=None, days_requested=None, options=None, local_vars_configuration=None):  # noqa: E501
        """AssetReportRefreshRequest - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._client_id = None
        self._secret = None
        self._asset_report_token = None
        self._days_requested = None
        self._options = None
        self.discriminator = None

        self.client_id = client_id
        self.secret = secret
        self.asset_report_token = asset_report_token
        if days_requested is not None:
            self.days_requested = days_requested
        if options is not None:
            self.options = options

    @property
    def client_id(self):
        """Gets the client_id of this AssetReportRefreshRequest.  # noqa: E501

        Your Plaid API `client_id`.  # noqa: E501

        :return: The client_id of this AssetReportRefreshRequest.  # noqa: E501
        :rtype: str
        """
        return self._client_id

    @client_id.setter
    def client_id(self, client_id):
        """Sets the client_id of this AssetReportRefreshRequest.

        Your Plaid API `client_id`.  # noqa: E501

        :param client_id: The client_id of this AssetReportRefreshRequest.  # noqa: E501
        :type client_id: str
        """
        if self.local_vars_configuration.client_side_validation and client_id is None:  # noqa: E501
            raise ValueError("Invalid value for `client_id`, must not be `None`")  # noqa: E501

        self._client_id = client_id

    @property
    def secret(self):
        """Gets the secret of this AssetReportRefreshRequest.  # noqa: E501

        Your Plaid API `secret`.  # noqa: E501

        :return: The secret of this AssetReportRefreshRequest.  # noqa: E501
        :rtype: str
        """
        return self._secret

    @secret.setter
    def secret(self, secret):
        """Sets the secret of this AssetReportRefreshRequest.

        Your Plaid API `secret`.  # noqa: E501

        :param secret: The secret of this AssetReportRefreshRequest.  # noqa: E501
        :type secret: str
        """
        if self.local_vars_configuration.client_side_validation and secret is None:  # noqa: E501
            raise ValueError("Invalid value for `secret`, must not be `None`")  # noqa: E501

        self._secret = secret

    @property
    def asset_report_token(self):
        """Gets the asset_report_token of this AssetReportRefreshRequest.  # noqa: E501

        The `asset_report_token` returned by the original call to `/asset_report/create`  # noqa: E501

        :return: The asset_report_token of this AssetReportRefreshRequest.  # noqa: E501
        :rtype: str
        """
        return self._asset_report_token

    @asset_report_token.setter
    def asset_report_token(self, asset_report_token):
        """Sets the asset_report_token of this AssetReportRefreshRequest.

        The `asset_report_token` returned by the original call to `/asset_report/create`  # noqa: E501

        :param asset_report_token: The asset_report_token of this AssetReportRefreshRequest.  # noqa: E501
        :type asset_report_token: str
        """
        if self.local_vars_configuration.client_side_validation and asset_report_token is None:  # noqa: E501
            raise ValueError("Invalid value for `asset_report_token`, must not be `None`")  # noqa: E501

        self._asset_report_token = asset_report_token

    @property
    def days_requested(self):
        """Gets the days_requested of this AssetReportRefreshRequest.  # noqa: E501

        The maximum number of days of history to include in the Asset Report. Must be an integer. If not specified, the value from the original call to `/asset_report/create` will be used.  # noqa: E501

        :return: The days_requested of this AssetReportRefreshRequest.  # noqa: E501
        :rtype: float
        """
        return self._days_requested

    @days_requested.setter
    def days_requested(self, days_requested):
        """Sets the days_requested of this AssetReportRefreshRequest.

        The maximum number of days of history to include in the Asset Report. Must be an integer. If not specified, the value from the original call to `/asset_report/create` will be used.  # noqa: E501

        :param days_requested: The days_requested of this AssetReportRefreshRequest.  # noqa: E501
        :type days_requested: float
        """
        if (self.local_vars_configuration.client_side_validation and
                days_requested is not None and days_requested > 730):  # noqa: E501
            raise ValueError("Invalid value for `days_requested`, must be a value less than or equal to `730`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                days_requested is not None and days_requested < 0):  # noqa: E501
            raise ValueError("Invalid value for `days_requested`, must be a value greater than or equal to `0`")  # noqa: E501

        self._days_requested = days_requested

    @property
    def options(self):
        """Gets the options of this AssetReportRefreshRequest.  # noqa: E501


        :return: The options of this AssetReportRefreshRequest.  # noqa: E501
        :rtype: AssetReportRefreshRequestOptions
        """
        return self._options

    @options.setter
    def options(self, options):
        """Sets the options of this AssetReportRefreshRequest.


        :param options: The options of this AssetReportRefreshRequest.  # noqa: E501
        :type options: AssetReportRefreshRequestOptions
        """

        self._options = options

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AssetReportRefreshRequest):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, AssetReportRefreshRequest):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    The Plaid API

    The Plaid REST API. Please see https://plaid.com/docs/api for more details.  # noqa: E501
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from plaid.generated_plaid.configuration import Configuration


class AssetReportItem(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'item_id': 'str',
        'institution_name': 'str',
        'institution_id': 'str',
        'date_last_updated': 'str',
        'accounts': 'list[AccountAssets]'
    }

    attribute_map = {
        'item_id': 'item_id',
        'institution_name': 'institution_name',
        'institution_id': 'institution_id',
        'date_last_updated': 'date_last_updated',
        'accounts': 'accounts'
    }

    def __init__(self, item_id=None, institution_name=None, institution_id=None, date_last_updated=None, accounts=None, local_vars_configuration=None):  # noqa: E501
        """AssetReportItem - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._item_id = None
        self._institution_name = None
        self._institution_id = None
        self._date_last_updated = None
        self._accounts = None
        self.discriminator = None

        if item_id is not None:
            self.item_id = item_id
        if institution_name is not None:
            self.institution_name = institution_name
        if institution_id is not None:
            self.institution_id = institution_id
        if date_last_updated is not None:
            self.date_last_updated = date_last_updated
        if accounts is not None:
            self.accounts = accounts

    @property
    def item_id(self):
        """Gets the item_id of this AssetReportItem.  # noqa: E501

        The `item_id` of the Item associated with this webhook, warning, or error  # noqa: E501

        :return: The item_id of this AssetReportItem.  # noqa: E501
        :rtype: str
        """
        return self._item_id

    @item_id.setter
    def item_id(self, item_id):
        """Sets the item_id of this AssetReportItem.

        The `item_id` of the Item associated with this webhook, warning, or error  # noqa: E501

        :param item_id: The item_id of this AssetReportItem.  # noqa: E501
        :type item_id: str
        """

        self._item_id = item_id

    @property
    def institution_name(self):
        """Gets the institution_name of this AssetReportItem.  # noqa: E501

        The full financial institution name associated with the Item.  # noqa: E501

        :return: The institution_name of this AssetReportItem.  # noqa: E501
        :rtype: str
        """
        return self._institution_name

    @institution_name.setter
    def institution_name(self, institution_name):
        """Sets the institution_name of this AssetReportItem.

        The full financial institution name associated with the Item.  # noqa: E501

        :param institution_name: The institution_name of this AssetReportItem.  # noqa: E501
        :type institution_name: str
        """

        self._institution_name = institution_name

    @property
    def institution_id(self):
        """Gets the institution_id of this AssetReportItem.  # noqa: E501

        The id of the financial institution associated with the Item.  # noqa: E501

        :return: The institution_id of this AssetReportItem.  # noqa: E501
        :rtype: str
        """
        return self._institution_id

    @institution_id.setter
    def institution_id(self, institution_id):
        """Sets the institution_id of this AssetReportItem.

        The id of the financial institution associated with the Item.  # noqa: E501

        :param institution_id: The institution_id of this AssetReportItem.  # noqa: E501
        :type institution_id: str
        """

        self._institution_id = institution_id

    @property
    def date_last_updated(self):
        """Gets the date_last_updated of this AssetReportItem.  # noqa: E501

        The date and time when this Item’s data was last retrieved from the financial institution, in ISO 8601 format.  # noqa: E501

        :return: The date_last_updated of this AssetReportItem.  # noqa: E501
        :rtype: str
        """
        return self._date_last_updated

    @date_last_updated.setter
    def date_last_updated(self, date_last_updated):
        """Sets the date_last_updated of this AssetReportItem.

        The date and time when this Item’s data was last retrieved from the financial institution, in ISO 8601 format.  # noqa: E501

        :param date_last_updated: The date_last_updated of this AssetReportItem.  # noqa: E501
        :type date_last_updated: str
        """

        self._date_last_updated = date_last_updated

    @property
    def accounts(self):
        """Gets the accounts of this AssetReportItem.  # noqa: E501

        Data about each of the accounts open on the Item.  # noqa: E501

        :return: The accounts of this AssetReportItem.  # noqa: E501
        :rtype: list[AccountAssets]
        """
        return self._accounts

    @accounts.setter
    def accounts(self, accounts):
        """Sets the accounts of this AssetReportItem.

        Data about each of the accounts open on the Item.  # noqa: E501

        :param accounts: The accounts of this AssetReportItem.  # noqa: E501
        :type accounts: list[AccountAssets]
        """

        self._accounts = accounts

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AssetReportItem):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, AssetReportItem):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    The Plaid API

    The Plaid REST API. Please see https://plaid.com/docs/api for more details.  # noqa: E501
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from plaid.generated_plaid.configuration import Configuration


class BankTransferEvent(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'event_id': 'float',
        'timestamp': 'str',
        'event_type': 'BankTransferEventType',
        'account_id': 'str',
        'bank_transfer_id': 'str',
        'bank_transfer_type': 'BankTransferType',
        'bank_transfer_amount': 'str',
        'bank_transfer_iso_currency_code': 'str',
        'failure_reason': 'BankTransferFailure',
        'direction': 'BankTransferDirection',
        'receiver_details': 'BankTransferReceiverDetails'
    }

    attribute_map = {
        'event_id': 'event_id',
        'timestamp': 'timestamp',
        'event_type': 'event_type',
        'account_id': 'account_id',
        'bank_transfer_id': 'bank_transfer_id',
        'bank_transfer_type': 'bank_transfer_type',
        'bank_transfer_amount': 'bank_transfer_amount',
        'bank_transfer_iso_currency_code': 'bank_transfer_iso_currency_code',
        'failure_reason': 'failure_reason',
        'direction': 'direction',
        'receiver_details': 'receiver_details'
    }

    def __init__(self, event_id=None, timestamp=None, event_type=None, account_id=None, bank_transfer_id=None, bank_transfer_type=None, bank_transfer_amount=None, bank_transfer_iso_currency_code=None, failure_reason=None, direction=None, receiver_details=None, local_vars_configuration=None):  # noqa: E501
        """BankTransferEvent - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._event_id = None
        self._timestamp = None
        self._event_type = None
        self._account_id = None
        self._bank_transfer_id = None
        self._bank_transfer_type = None
        self._bank_transfer_amount = None
        self._bank_transfer_iso_currency_code = None
        self._failure_reason = None
        self._direction = None
        self._receiver_details = None
        self.discriminator = None

        if event_id is not None:
            self.event_id = event_id
        if timestamp is not None:
            self.timestamp = timestamp
        if event_type is not None:
            self.event_type = event_type
        if account_id is not None:
            self.account_id = account_id
        if bank_transfer_id is not None:
            self.bank_transfer_id = bank_transfer_id
        if bank_transfer_type is not None:
            self.bank_transfer_type = bank_transfer_type
        if bank_transfer_amount is not None:
            self.bank_transfer_amount = bank_transfer_amount
        if bank_transfer_iso_currency_code is not None:
            self.bank_transfer_iso_currency_code = bank_transfer_iso_currency_code
        self.failure_reason = failure_reason
        if direction is not None:
            self.direction = direction
        self.receiver_details = receiver_details

    @property
    def event_id(self):
        """Gets the event_id of this BankTransferEvent.  # noqa: E501

        Plaid’s unique identifier for this event. IDs are sequential unsigned 64-bit integers.  # noqa: E501

        :return: The event_id of this BankTransferEvent.  # noqa: E501
        :rtype: float
        """
        return self._event_id

    @event_id.setter
    def event_id(self, event_id):
        """Sets the event_id of this BankTransferEvent.

        Plaid’s unique identifier for this event. IDs are sequential unsigned 64-bit integers.  # noqa: E501

        :param event_id: The event_id of this BankTransferEvent.  # noqa: E501
        :type event_id: float
        """

        self._event_id = event_id

    @property
    def timestamp(self):
        """Gets the timestamp of this BankTransferEvent.  # noqa: E501

        The datetime when this event occurred. This will be of the form `2006-01-02T15:04:05Z`.  # noqa: E501

        :return: The timestamp of this BankTransferEvent.  # noqa: E501
        :rtype: str
        """
        return self._timestamp

    @timestamp.setter
    def timestamp(self, timestamp):
        """Sets the timestamp of this BankTransferEvent.

        The datetime when this event occurred. This will be of the form `2006-01-02T15:04:05Z`.  # noqa: E501

        :param timestamp: The timestamp of this BankTransferEvent.  # noqa: E501
        :type timestamp: str
        """

        self._timestamp = timestamp

    @property
    def event_type(self):
        """Gets the event_type of this BankTransferEvent.  # noqa: E501


        :return: The event_type of this BankTransferEvent.  # noqa: E501
        :rtype: BankTransferEventType
        """
        return self._event_type

    @event_type.setter
    def event_type(self, event_type):
        """Sets the event_type of this BankTransferEvent.


        :param event_type: The event_type of this BankTransferEvent.  # noqa: E501
        :type event_type: BankTransferEventType
        """

        self._event_type = event_type

    @property
    def account_id(self):
        """Gets the account_id of this BankTransferEvent.  # noqa: E501

        The account ID associated with the bank transfer.  # noqa: E501

        :return: The account_id of this BankTransferEvent.  # noqa: E501
        :rtype: str
        """
        return self._account_id

    @account_id.setter
    def account_id(self, account_id):
        """Sets the account_id of this BankTransferEvent.

        The account ID associated with the bank transfer.  # noqa: E501

        :param account_id: The account_id of this BankTransferEvent.  # noqa: E501
        :type account_id: str
        """

        self._account_id = account_id

    @property
    def bank_transfer_id(self):
        """Gets the bank_transfer_id of this BankTransferEvent.  # noqa: E501

        Plaid’s unique identifier for a bank transfer.  # noqa: E501

        :return: The bank_transfer_id of this BankTransferEvent.  # noqa: E501
        :rtype: str
        """
        return self._bank_transfer_id

    @bank_transfer_id.setter
    def bank_transfer_id(self, bank_transfer_id):
        """Sets the bank_transfer_id of this BankTransferEvent.

        Plaid’s unique identifier for a bank transfer.  # noqa: E501

        :param bank_transfer_id: The bank_transfer_id of this BankTransferEvent.  # noqa: E501
        :type bank_transfer_id: str
        """

        self._bank_transfer_id = bank_transfer_id

    @property
    def bank_transfer_type(self):
        """Gets the bank_transfer_type of this BankTransferEvent.  # noqa: E501


        :return: The bank_transfer_type of this BankTransferEvent.  # noqa: E501
        :rtype: BankTransferType
        """
        return self._bank_transfer_type

    @bank_transfer_type.setter
    def bank_transfer_type(self, bank_transfer_type):
        """Sets the bank_transfer_type of this BankTransferEvent.


        :param bank_transfer_type: The bank_transfer_type of this BankTransferEvent.  # noqa: E501
        :type bank_transfer_type: BankTransferType
        """

        self._bank_transfer_type = bank_transfer_type

    @property
    def bank_transfer_amount(self):
        """Gets the bank_transfer_amount of this BankTransferEvent.  # noqa: E501

        The bank transfer amount.  # noqa: E501

        :return: The bank_transfer_amount of this BankTransferEvent.  # noqa: E501
        :rtype: str
        """
        return self._bank_transfer_amount

    @bank_transfer_amount.setter
    def bank_transfer_amount(self, bank_transfer_amount):
        """Sets the bank_transfer_amount of this BankTransferEvent.

        The bank transfer amount.  # noqa: E501

        :param bank_transfer_amount: The bank_transfer_amount of this BankTransferEvent.  # noqa: E501
        :type bank_transfer_amount: str
        """

        self._bank_transfer_amount = bank_transfer_amount

    @property
    def bank_transfer_iso_currency_code(self):
        """Gets the bank_transfer_iso_currency_code of this BankTransferEvent.  # noqa: E501

        The currency of the bank transfer amount.  # noqa: E501

        :return: The bank_transfer_iso_currency_code of this BankTransferEvent.  # noqa: E501
        :rtype: str
        """
        return self._bank_transfer_iso_currency_code

    @bank_transfer_iso_currency_code.setter
    def bank_transfer_iso_currency_code(self, bank_transfer_iso_currency_code):
        """Sets the bank_transfer_iso_currency_code of this BankTransferEvent.

        The currency of the bank transfer amount.  # noqa: E501

        :param bank_transfer_iso_currency_code: The bank_transfer_iso_currency_code of this BankTransferEvent.  # noqa: E501
        :type bank_transfer_iso_currency_code: str
        """

        self._bank_transfer_iso_currency_code = bank_transfer_iso_currency_code

    @property
    def failure_reason(self):
        """Gets the failure_reason of this BankTransferEvent.  # noqa: E501


        :return: The failure_reason of this BankTransferEvent.  # noqa: E501
        :rtype: BankTransferFailure
        """
        return self._failure_reason

    @failure_reason.setter
    def failure_reason(self, failure_reason):
        """Sets the failure_reason of this BankTransferEvent.


        :param failure_reason: The failure_reason of this BankTransferEvent.  # noqa: E501
        :type failure_reason: BankTransferFailure
        """

        self._failure_reason = failure_reason

    @property
    def direction(self):
        """Gets the direction of this BankTransferEvent.  # noqa: E501


        :return: The direction of this BankTransferEvent.  # noqa: E501
        :rtype: BankTransferDirection
        """
        return self._direction

    @direction.setter
    def direction(self, direction):
        """Sets the direction of this BankTransferEvent.


        :param direction: The direction of this BankTransferEvent.  # noqa: E501
        :type direction: BankTransferDirection
        """

        self._direction = direction

    @property
    def receiver_details(self):
        """Gets the receiver_details of this BankTransferEvent.  # noqa: E501


        :return: The receiver_details of this BankTransferEvent.  # noqa: E501
        :rtype: BankTransferReceiverDetails
        """
        return self._receiver_details

    @receiver_details.setter
    def receiver_details(self, receiver_details):
        """Sets the receiver_details of this BankTransferEvent.


        :param receiver_details: The receiver_details of this BankTransferEvent.  # noqa: E501
        :type receiver_details: BankTransferReceiverDetails
        """

        self._receiver_details = receiver_details

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BankTransferEvent):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, BankTransferEvent):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    The Plaid API

    The Plaid REST API. Please see https://plaid.com/docs/api for more details.  # noqa: E501
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from plaid.generated_plaid.configuration import Configuration


class StudentLoan(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'account_id': 'str',
        'account_number': 'str',
        'disbursement_dates': 'list[str]',
        'expected_payoff_date': 'str',
        'guarantor': 'str',
        'interest_rate_percentage': 'float',
        'is_overdue': 'bool',
        'last_payment_amount': 'float',
        'last_payment_date': 'str',
        'last_statement_balance': 'float',
        'last_statement_issue_date': 'str',
        'loan_name': 'str',
        'loan_status': 'StudentLoanStatus',
        'minimum_payment_amount': 'float',
        'next_payment_due_date': 'str',
        'origination_date': 'str',
        'origination_principal_amount': 'float',
        'outstanding_interest_amount': 'float',
        'payment_reference_number': 'str',
        'pslf_status': 'PSLFStatus',
        'repayment_plan': 'StudentRepaymentPlan',
        'sequence_number': 'str',
        'servicer_address': 'ServicerAddressData',
        'ytd_interest_paid': 'float',
        'ytd_principal_paid': 'float'
    }

    attribute_map = {
        'account_id': 'account_id',
        'account_number': 'account_number',
        'disbursement_dates': 'disbursement_dates',
        'expected_payoff_date': 'expected_payoff_date',
        'guarantor': 'guarantor',
        'interest_rate_percentage': 'interest_rate_percentage',
        'is_overdue': 'is_overdue',
        'last_payment_amount': 'last_payment_amount',
        'last_payment_date': 'last_payment_date',
        'last_statement_balance': 'last_statement_balance',
        'last_statement_issue_date': 'last_statement_issue_date',
        'loan_name': 'loan_name',
        'loan_status': 'loan_status',
        'minimum_payment_amount': 'minimum_payment_amount',
        'next_payment_due_date': 'next_payment_due_date',
        'origination_date': 'origination_date',
        'origination_principal_amount': 'origination_principal_amount',
        'outstanding_interest_amount': 'outstanding_interest_amount',
        'payment_reference_number': 'payment_reference_number',
        'pslf_status': 'pslf_status',
        'repayment_plan': 'repayment_plan',
        'sequence_number': 'sequence_number',
        'servicer_address': 'servicer_address',
        'ytd_interest_paid': 'ytd_interest_paid',
        'ytd_principal_paid': 'ytd_principal_paid'
    }

    def __init__(self, account_id=None, account_number=None, disbursement_dates=None, expected_payoff_date=None, guarantor=None, interest_rate_percentage=None, is_overdue=None, last_payment_amount=None, last_payment_date=None, last_statement_balance=None, last_statement_issue_date=None, loan_name=None, loan_status=None, minimum_payment_amount=None, next_payment_due_date=None, origination_date=None, origination_principal_amount=None, outstanding_interest_amount=None, payment_reference_number=None, pslf_status=None, repayment_plan=None, sequence_number=None, servicer_address=None, ytd_interest_paid=None, ytd_principal_paid=None, local_vars_configuration=None):  # noqa: E501
        """StudentLoan - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._account_id = None
        self._account_number = None
        self._disbursement_dates = None
        self._expected_payoff_date = None
        self._guarantor = None
        self._interest_rate_percentage = None
        self._is_overdue = None
        self._last_payment_amount = None
        self._last_payment_date = None
        self._last_statement_balance = None
        self._last_statement_issue_date = None
        self._loan_name = None
        self._loan_status = None
        self._minimum_payment_amount = None
        self._next_payment_due_date = None
        self._origination_date = None
        self._origination_principal_amount = None
        self._outstanding_interest_amount = None
        self._payment_reference_number = None
        self._pslf_status = None
        self._repayment_plan = None
        self._sequence_number = None
        self._servicer_address = None
        self._ytd_interest_paid = None
        self._ytd_principal_paid = None
        self.discriminator = None

        self.account_id = account_id
        self.account_number = account_number
        self.disbursement_dates = disbursement_dates
        self.expected_payoff_date = expected_payoff_date
        self.guarantor = guarantor
        if interest_rate_percentage is not None:
            self.interest_rate_percentage = interest_rate_percentage
        self.is_overdue = is_overdue
        self.last_payment_amount = last_payment_amount
        self.last_payment_date = last_payment_date
        self.last_statement_balance = last_statement_balance
        self.last_statement_issue_date = last_statement_issue_date
        self.loan_name = loan_name
        if loan_status is not None:
            self.loan_status = loan_status
        self.minimum_payment_amount = minimum_payment_amount
        self.next_payment_due_date = next_payment_due_date
        self.origination_date = origination_date
        self.origination_principal_amount = origination_principal_amount
        self.outstanding_interest_amount = outstanding_interest_amount
        self.payment_reference_number = payment_reference_number
        if pslf_status is not None:
            self.pslf_status = pslf_status
        if repayment_plan is not None:
            self.repayment_plan = repayment_plan
        self.sequence_number = sequence_number
        if servicer_address is not None:
            self.servicer_address = servicer_address
        self.ytd_interest_paid = ytd_interest_paid
        self.ytd_principal_paid = ytd_principal_paid

    @property
    def account_id(self):
        """Gets the account_id of this StudentLoan.  # noqa: E501

        The ID of the account that this liability belongs to.  # noqa: E501

        :return: The account_id of this StudentLoan.  # noqa: E501
        :rtype: str
        """
        return self._account_id

    @account_id.setter
    def account_id(self, account_id):
        """Sets the account_id of this StudentLoan.

        The ID of the account that this liability belongs to.  # noqa: E501

        :param account_id: The account_id of this StudentLoan.  # noqa: E501
        :type account_id: str
        """

        self._account_id = account_id

    @property
    def account_number(self):
        """Gets the account_number of this StudentLoan.  # noqa: E501

        The account number of the loan.  # noqa: E501

        :return: The account_number of this StudentLoan.  # noqa: E501
        :rtype: str
        """
        return self._account_number

    @account_number.setter
    def account_number(self, account_number):
        """Sets the account_number of this StudentLoan.

        The account number of the loan.  # noqa: E501

        :param account_number: The account_number of this StudentLoan.  # noqa: E501
        :type account_number: str
        """

        self._account_number = account_number

    @property
    def disbursement_dates(self):
        """Gets the disbursement_dates of this StudentLoan.  # noqa: E501

        The dates on which loaned funds were disbursed or will be disbursed. These are often in the past. Dates are returned in an ISO 8601 format (YYYY-MM-DD).  # noqa: E501

        :return: The disbursement_dates of this StudentLoan.  # noqa: E501
        :rtype: list[str]
        """
        return self._disbursement_dates

    @disbursement_dates.setter
    def disbursement_dates(self, disbursement_dates):
        """Sets the disbursement_dates of this StudentLoan.

        The dates on which loaned funds were disbursed or will be disbursed. These are often in the past. Dates are returned in an ISO 8601 format (YYYY-MM-DD).  # noqa: E501

        :param disbursement_dates: The disbursement_dates of this StudentLoan.  # noqa: E501
        :type disbursement_dates: list[str]
        """

        self._disbursement_dates = disbursement_dates

    @property
    def expected_payoff_date(self):
        """Gets the expected_payoff_date of this StudentLoan.  # noqa: E501

        The date when the student loan is expected to be paid off. Availability for this field is limited. Dates are returned in an ISO 8601 format (YYYY-MM-DD).  # noqa: E501

        :return: The expected_payoff_date of this StudentLoan.  # noqa: E501
        :rtype: str
        """
        return self._expected_payoff_date

    @expected_payoff_date.setter
    def expected_payoff_date(self, expected_payoff_date):
        """Sets the expected_payoff_date of this StudentLoan.

        The date when the student loan is expected to be paid off. Availability for this field is limited. Dates are returned in an ISO 8601 format (YYYY-MM-DD).  # noqa: E501

        :param expected_payoff_date: The expected_payoff_date of this StudentLoan.  # noqa: E501
        :type expected_payoff_date: str
        """

        self._expected_payoff_date = expected_payoff_date

    @property
    def guarantor(self):
        """Gets the guarantor of this StudentLoan.  # noqa: E501

        The guarantor of the student loan.  # noqa: E501

        :return: The guarantor of this StudentLoan.  # noqa: E501
        :rtype: str
        """
        return self._guarantor

    @guarantor.setter
    def guarantor(self, guarantor):
        """Sets the guarantor of this StudentLoan.

        The guarantor of the student loan.  # noqa: E501

        :param guarantor: The guarantor of this StudentLoan.  # noqa: E501
        :type guarantor: str
        """

        self._guarantor = guarantor

    @property
    def interest_rate_percentage(self):
        """Gets the interest_rate_percentage of this StudentLoan.  # noqa: E501

        The interest rate on the loan as a percentage.  # noqa: E501

        :return: The interest_rate_percentage of this StudentLoan.  # noqa: E501
        :rtype: float
        """
        return self._interest_rate_percentage

    @interest_rate_percentage.setter
    def interest_rate_percentage(self, interest_rate_percentage):
        """Sets the interest_rate_percentage of this StudentLoan.

        The interest rate on the loan as a percentage.  # noqa: E501

        :param interest_rate_percentage: The interest_rate_percentage of this StudentLoan.  # noqa: E501
        :type interest_rate_percentage: float
        """

        self._interest_rate_percentage = interest_rate_percentage

    @property
    def is_overdue(self):
        """Gets the is_overdue of this StudentLoan.  # noqa: E501

        `true` if a payment is currently overdue. Availability for this field is limited.  # noqa: E501

        :return: The is_overdue of this StudentLoan.  # noqa: E501
        :rtype: bool
        """
        return self._is_overdue

    @is_overdue.setter
    def is_overdue(self, is_overdue):
        """Sets the is_overdue of this StudentLoan.

        `true` if a payment is currently overdue. Availability for this field is limited.  # noqa: E501

        :param is_overdue: The is_overdue of this StudentLoan.  # noqa: E501
        :type is_overdue: bool
        """

        self._is_overdue = is_overdue

    @property
    def last_payment_amount(self):
        """Gets the last_payment_amount of this StudentLoan.  # noqa: E501

        The amount of the last payment.  # noqa: E501

        :return: The last_payment_amount of this StudentLoan.  # noqa: E501
        :rtype: float
        """
        return self._last_payment_amount

    @last_payment_amount.setter
    def last_payment_amount(self, last_payment_amount):
        """Sets the last_payment_amount of this StudentLoan.

        The amount of the last payment.  # noqa: E501

        :param last_payment_amount: The last_payment_amount of this StudentLoan.  # noqa: E501
        :type last_payment_amount: float
        """

        self._last_payment_amount = last_payment_amount

    @property
    def last_payment_date(self):
        """Gets the last_payment_date of this StudentLoan.  # noqa: E501

        The date of the last payment. Dates are returned in an ISO 8601 format (YYYY-MM-DD).  # noqa: E501

        :return: The last_payment_date of this StudentLoan.  # noqa: E501
        :rtype: str
        """
        return self._last_payment_date

    @last_payment_date.setter
    def last_payment_date(self, last_payment_date):
        """Sets the last_payment_date of this StudentLoan.

        The date of the last payment. Dates are returned in an ISO 8601 format (YYYY-MM-DD).  # noqa: E501

        :param last_payment_date: The last_payment_date of this StudentLoan.  # noqa: E501
        :type last_payment_date: str
        """

        self._last_payment_date = last_payment_date

    @property
    def last_statement_balance(self):
        """Gets the last_statement_balance of this StudentLoan.  # noqa: E501

        The outstanding balance on the last statement. This field could also be interpreted as the next payment due. Availability for this field is limited.   # noqa: E501

        :return: The last_statement_balance of this StudentLoan.  # noqa: E501
        :rtype: float
        """
        return self._last_statement_balance

    @last_statement_balance.setter
    def last_statement_balance(self, last_statement_balance):
        """Sets the last_statement_balance of this StudentLoan.

        The outstanding balance on the last statement. This field could also be interpreted as the next payment due. Availability for this field is limited.   # noqa: E501

        :param last_statement_balance: The last_statement_balance of this StudentLoan.  # noqa: E501
        :type last_statement_balance: float
        """

        self._last_statement_balance = last_statement_balance

    @property
    def last_statement_issue_date(self):
        """Gets the last_statement_issue_date of this StudentLoan.  # noqa: E501

        The date of the last statement. Dates are returned in an ISO 8601 format (YYYY-MM-DD).  # noqa: E501

        :return: The last_statement_issue_date of this StudentLoan.  # noqa: E501
        :rtype: str
        """
        return self._last_statement_issue_date

    @last_statement_issue_date.setter
    def last_statement_issue_date(self, last_statement_issue_date):
        """Sets the last_statement_issue_date of this StudentLoan.

        The date of the last statement. Dates are returned in an ISO 8601 format (YYYY-MM-DD).  # noqa: E501

        :param last_statement_issue_date: The last_statement_issue_date of this StudentLoan.  # noqa: E501
        :type last_statement_issue_date: str
        """

        self._last_statement_issue_date = last_statement_issue_date

    @property
    def loan_name(self):
        """Gets the loan_name of this StudentLoan.  # noqa: E501

        The type of loan, e.g., \"Consolidation Loans\".  # noqa: E501

        :return: The loan_name of this StudentLoan.  # noqa: E501
        :rtype: str
        """
        return self._loan_name

    @loan_name.setter
    def loan_name(self, loan_name):
        """Sets the loan_name of this StudentLoan.

        The type of loan, e.g., \"Consolidation Loans\".  # noqa: E501

        :param loan_name: The loan_name of this StudentLoan.  # noqa: E501
        :type loan_name: str
        """

        self._loan_name = loan_name

    @property
    def loan_status(self):
        """Gets the loan_status of this StudentLoan.  # noqa: E501


        :return: The loan_status of this StudentLoan.  # noqa: E501
        :rtype: StudentLoanStatus
        """
        return self._loan_status

    @loan_status.setter
    def loan_status(self, loan_status):
        """Sets the loan_status of this StudentLoan.


        :param loan_status: The loan_status of this StudentLoan.  # noqa: E501
        :type loan_status: StudentLoanStatus
        """

        self._loan_status = loan_status

    @property
    def minimum_payment_amount(self):
        """Gets the minimum_payment_amount of this StudentLoan.  # noqa: E501

        The minimum payment due for the next billing cycle. There are some exceptions: Some institutions require a minimum payment across all loans associated with an account number. Our API presents that same minimum payment amount on each loan. The institutions that do this are: Great Lakes ( `ins_116861`), Firstmark (`ins_116295`), Commonbond Firstmark Services (`ins_116950`), Nelnet (`ins_116528`), EdFinancial Services (`ins_116304`), Granite State (`ins_116308`), and Oklahoma Student Loan Authority (`ins_116945`). Firstmark (`ins_116295` ) will display as $0 if there is an autopay program in effect.  # noqa: E501

        :return: The minimum_payment_amount of this StudentLoan.  # noqa: E501
        :rtype: float
        """
        return self._minimum_payment_amount

    @minimum_payment_amount.setter
    def minimum_payment_amount(self, minimum_payment_amount):
        """Sets the minimum_payment_amount of this StudentLoan.

        The minimum payment due for the next billing cycle. There are some exceptions: Some institutions require a minimum payment across all loans associated with an account number. Our API presents that same minimum payment amount on each loan. The institutions that do this are: Great Lakes ( `ins_116861`), Firstmark (`ins_116295`), Commonbond Firstmark Services (`ins_116950`), Nelnet (`ins_116528`), EdFinancial Services (`ins_116304`), Granite State (`ins_116308`), and Oklahoma Student Loan Authority (`ins_116945`). Firstmark (`ins_116295` ) will display as $0 if there is an autopay program in effect.  # noqa: E501

        :param minimum_payment_amount: The minimum_payment_amount of this StudentLoan.  # noqa: E501
        :type minimum_payment_amount: float
        """

        self._minimum_payment_amount = minimum_payment_amount

    @property
    def next_payment_due_date(self):
        """Gets the next_payment_due_date of this StudentLoan.  # noqa: E501

        The due date for the next payment. The due date is `null` if a payment is not expected. A payment is not expected if `loan_status.type` is `deferment`, `in_school`, `consolidated`, `paid in full`, or `transferred`. Dates are returned in an ISO 8601 format (YYYY-MM-DD).  # noqa: E501

        :return: The next_payment_due_date of this StudentLoan.  # noqa: E501
        :rtype: str
        """
        return self._next_payment_due_date

    @next_payment_due_date.setter
    def next_payment_due_date(self, next_payment_due_date):
        """Sets the next_payment_due_date of this StudentLoan.

        The due date for the next payment. The due date is `null` if a payment is not expected. A payment is not expected if `loan_status.type` is `deferment`, `in_school`, `consolidated`, `paid in full`, or `transferred`. Dates are returned in an ISO 8601 format (YYYY-MM-DD).  # noqa: E501

        :param next_payment_due_date: The next_payment_due_date of this StudentLoan.  # noqa: E501
        :type next_payment_due_date: str
        """

        self._next_payment_due_date = next_payment_due_date

    @property
    def origination_date(self):
        """Gets the origination_date of this StudentLoan.  # noqa: E501

        The date on which the loan was initially lent. Dates are returned in an ISO 8601 format (YYYY-MM-DD).   # noqa: E501

        :return: The origination_date of this StudentLoan.  # noqa: E501
        :rtype: str
        """
        return self._origination_date

    @origination_date.setter
    def origination_date(self, origination_date):
        """Sets the origination_date of this StudentLoan.

        The date on which the loan was initially lent. Dates are returned in an ISO 8601 format (YYYY-MM-DD).   # noqa: E501

        :param origination_date: The origination_date of this StudentLoan.  # noqa: E501
        :type origination_date: str
        """

        self._origination_date = origination_date

    @property
    def origination_principal_amount(self):
        """Gets the origination_principal_amount of this StudentLoan.  # noqa: E501

        The original principal balance of the loan.  # noqa: E501

        :return: The origination_principal_amount of this StudentLoan.  # noqa: E501
        :rtype: float
        """
        return self._origination_principal_amount

    @origination_principal_amount.setter
    def origination_principal_amount(self, origination_principal_amount):
        """Sets the origination_principal_amount of this StudentLoan.

        The original principal balance of the loan.  # noqa: E501

        :param origination_principal_amount: The origination_principal_amount of this StudentLoan.  # noqa: E501
        :type origination_principal_amount: float
        """

        self._origination_principal_amount = origination_principal_amount

    @property
    def outstanding_interest_amount(self):
        """Gets the outstanding_interest_amount of this StudentLoan.  # noqa: E501

        The total dollar amount of the accrued interest balance. For Sallie Mae ( `ins_116944`), this amount is included in the current balance of the loan, so this field will return as `null`.  # noqa: E501

        :return: The outstanding_interest_amount of this StudentLoan.  # noqa: E501
        :rtype: float
        """
        return self._outstanding_interest_amount

    @outstanding_interest_amount.setter
    def outstanding_interest_amount(self, outstanding_interest_amount):
        """Sets the outstanding_interest_amount of this StudentLoan.

        The total dollar amount of the accrued interest balance. For Sallie Mae ( `ins_116944`), this amount is included in the current balance of the loan, so this field will return as `null`.  # noqa: E501

        :param outstanding_interest_amount: The outstanding_interest_amount of this StudentLoan.  # noqa: E501
        :type outstanding_interest_amount: float
        """

        self._outstanding_interest_amount = outstanding_interest_amount

    @property
    def payment_reference_number(self):
        """Gets the payment_reference_number of this StudentLoan.  # noqa: E501

        The relevant account number that should be used to reference this loan for payments. In the majority of cases, `payment_reference_number` will match a`ccount_number,` but in some institutions, such as Great Lakes (`ins_116861`), it will be different.  # noqa: E501

        :return: The payment_reference_number of this StudentLoan.  # noqa: E501
        :rtype: str
        """
        return self._payment_reference_number

    @payment_reference_number.setter
    def payment_reference_number(self, payment_reference_number):
        """Sets the payment_reference_number of this StudentLoan.

        The relevant account number that should be used to reference this loan for payments. In the majority of cases, `payment_reference_number` will match a`ccount_number,` but in some institutions, such as Great Lakes (`ins_116861`), it will be different.  # noqa: E501

        :param payment_reference_number: The payment_reference_number of this StudentLoan.  # noqa: E501
        :type payment_reference_number: str
        """

        self._payment_reference_number = payment_reference_number

    @property
    def pslf_status(self):
        """Gets the pslf_status of this StudentLoan.  # noqa: E501


        :return: The pslf_status of this StudentLoan.  # noqa: E501
        :rtype: PSLFStatus
        """
        return self._pslf_status

    @pslf_status.setter
    def pslf_status(self, pslf_status):
        """Sets the pslf_status of this StudentLoan.


        :param pslf_status: The pslf_status of this StudentLoan.  # noqa: E501
        :type pslf_status: PSLFStatus
        """

        self._pslf_status = pslf_status

    @property
    def repayment_plan(self):
        """Gets the repayment_plan of this StudentLoan.  # noqa: E501


        :return: The repayment_plan of this StudentLoan.  # noqa: E501
        :rtype: StudentRepaymentPlan
        """
        return self._repayment_plan

    @repayment_plan.setter
    def repayment_plan(self, repayment_plan):
        """Sets the repayment_plan of this StudentLoan.


        :param repayment_plan: The repayment_plan of this StudentLoan.  # noqa: E501
        :type repayment_plan: StudentRepaymentPlan
        """

        self._repayment_plan = repayment_plan

    @property
    def sequence_number(self):
        """Gets the sequence_number of this StudentLoan.  # noqa: E501

        The sequence number of the student loan. Heartland ECSI (`ins_116948`) does not make this field available.  # noqa: E501

        :return: The sequence_number of this StudentLoan.  # noqa: E501
        :rtype: str
        """
        return self._sequence_number

    @sequence_number.setter
    def sequence_number(self, sequence_number):
        """Sets the sequence_number of this StudentLoan.

        The sequence number of the student loan. Heartland ECSI (`ins_116948`) does not make this field available.  # noqa: E501

        :param sequence_number: The sequence_number of this StudentLoan.  # noqa: E501
        :type sequence_number: str
        """

        self._sequence_number = sequence_number

    @property
    def servicer_address(self):
        """Gets the servicer_address of this StudentLoan.  # noqa: E501


        :return: The servicer_address of this StudentLoan.  # noqa: E501
        :rtype: ServicerAddressData
        """
        return self._servicer_address

    @servicer_address.setter
    def servicer_address(self, servicer_address):
        """Sets the servicer_address of this StudentLoan.


        :param servicer_address: The servicer_address of this StudentLoan.  # noqa: E501
        :type servicer_address: ServicerAddressData
        """

        self._servicer_address = servicer_address

    @property
    def ytd_interest_paid(self):
        """Gets the ytd_interest_paid of this StudentLoan.  # noqa: E501

        The year to date (YTD) interest paid. Availability for this field is limited.  # noqa: E501

        :return: The ytd_interest_paid of this StudentLoan.  # noqa: E501
        :rtype: float
        """
        return self._ytd_interest_paid

    @ytd_interest_paid.setter
    def ytd_interest_paid(self, ytd_interest_paid):
        """Sets the ytd_interest_paid of this StudentLoan.

        The year to date (YTD) interest paid. Availability for this field is limited.  # noqa: E501

        :param ytd_interest_paid: The ytd_interest_paid of this StudentLoan.  # noqa: E501
        :type ytd_interest_paid: float
        """

        self._ytd_interest_paid = ytd_interest_paid

    @property
    def ytd_principal_paid(self):
        """Gets the ytd_principal_paid of this StudentLoan.  # noqa: E501

        The year to date (YTD) principal paid. Availability for this field is limited.  # noqa: E501

        :return: The ytd_principal_paid of this StudentLoan.  # noqa: E501
        :rtype: float
        """
        return self._ytd_principal_paid

    @ytd_principal_paid.setter
    def ytd_principal_paid(self, ytd_principal_paid):
        """Sets the ytd_principal_paid of this StudentLoan.

        The year to date (YTD) principal paid. Availability for this field is limited.  # noqa: E501

        :param ytd_principal_paid: The ytd_principal_paid of this StudentLoan.  # noqa: E501
        :type ytd_principal_paid: float
        """

        self._ytd_principal_paid = ytd_principal_paid

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, StudentLoan):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, StudentLoan):
            return True

        return self.to_dict() != other.to_dict()



import time

from tests.integration.util import (
    create_client,
    SANDBOX_INSTITUTION
)
from random import random
from random import seed
from plaid.errors import BankTransferError

access_token = None
account_id = None
num_retries = 10

def setup_module(module):
    client = create_client()
    pt_response = client.Sandbox.public_token.create(
        SANDBOX_INSTITUTION, ['auth'])
    exchange_response = client.Item.public_token.exchange(
        pt_response['public_token'])
    global access_token
    access_token = exchange_response['access_token']
    accounts_response = client.Accounts.get(access_token)
    account = next(acct for acct in accounts_response['accounts'] if acct['type'] == 'depository')
    global account_id
    account_id = account['account_id']
    seed()

def create_bank_transfer(client):
    bt_response = client.BankTransfer.create(
        str(random()),
        access_token,
        account_id,
        'credit',
        'ach',
        '1.00',
        'USD',
        'test',
        {'legal_name': 'Firstname Lastname'},
        metadata=None,
        ach_class='ppd',
        custom_tag=None,
    )
    assert bt_response is not None
    return bt_response['bank_transfer']

def poll_for_response(checks):
    success = False
    for i in range(num_retries):
        try:
            checks()
            success = True
            break
        except AssertionError:
            continue
    assert success

def test_create():
    client = create_client()
    bt = create_bank_transfer(client)
    assert bt is not None
    assert bt['id'] is not None

def test_cancel_success():
    client = create_client()
    bt = create_bank_transfer(client)
    def checks():
        cancel_response = client.BankTransfer.cancel(bt['id'])
        assert cancel_response is not None
    poll_for_response(checks)

def test_cancel_failure():
    client = create_client()
    bt = create_bank_transfer(client)
    simulate_response = client.Sandbox.bank_transfer.simulate(bt['id'], 'posted')
    assert simulate_response is not None
    # allow event simulation to process so we don't inadvertently succeed
    time.sleep(0.1)
    # assert that a BankTransferError is thrown
    try:
        client.BankTransfer.cancel(bt['id'])
        # cancel should not succeed
        assert False
    except BankTransferError:
        assert True
    except:
        assert False

def test_list_events():
    client = create_client()
    bt = create_bank_transfer(client)
    bt_id = bt['id']
    simulate_response = client.Sandbox.bank_transfer.simulate(bt['id'], 'posted')
    assert simulate_response is not None
    def checks():
        list_events_response = client.BankTransfer.list_events(bank_transfer_id=bt_id)
        assert list_events_response is not None
        assert list_events_response['bank_transfer_events'] is not None
        assert len(list_events_response['bank_transfer_events']) == 2
    poll_for_response(checks)

def test_sync_events():
    client = create_client()
    bt = create_bank_transfer(client)
    def checks():
        sync_response = client.BankTransfer.sync_events(0)
        assert sync_response is not None
        assert sync_response['bank_transfer_events'] is not None
        assert len(sync_response['bank_transfer_events']) > 0
    poll_for_response(checks)

def test_get():
    client = create_client()
    bt = create_bank_transfer(client)
    def checks():
        get_response = client.BankTransfer.get(bt['id'])
        assert bt == get_response['bank_transfer']
    poll_for_response(checks)

def test_list():
    client = create_client()
    bt = create_bank_transfer(client)
    def checks():
        list_response = client.BankTransfer.list(count=1)
        assert list_response is not None
        assert len(list_response['bank_transfers']) == 1
        assert list_response['bank_transfers'][0] == bt
    poll_for_response(checks)

def test_balance_get():
    client = create_client()
    balance_response = client.BankTransfer.balance.get()
    assert balance_response is not None
    assert balance_response['balance'] is not None
    assert balance_response['balance']['available'] is not None

def test_migrate_account():
    client = create_client()
    migrate_response = client.BankTransfer.migrate_account('100000000', '121122676', 'checking')
    assert migrate_response is not None
    assert migrate_response['access_token'] is not None



# coding: utf-8

"""
    The Plaid API

    The Plaid REST API. Please see https://plaid.com/docs/api for more details.  # noqa: E501
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from plaid.generated_plaid.configuration import Configuration


class InstitutionsGetResponse(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'institutions': 'list[Institution]',
        'total': 'int',
        'request_id': 'str'
    }

    attribute_map = {
        'institutions': 'institutions',
        'total': 'total',
        'request_id': 'request_id'
    }

    def __init__(self, institutions=None, total=None, request_id=None, local_vars_configuration=None):  # noqa: E501
        """InstitutionsGetResponse - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._institutions = None
        self._total = None
        self._request_id = None
        self.discriminator = None

        if institutions is not None:
            self.institutions = institutions
        if total is not None:
            self.total = total
        if request_id is not None:
            self.request_id = request_id

    @property
    def institutions(self):
        """Gets the institutions of this InstitutionsGetResponse.  # noqa: E501

        A list of Plaid Institution  # noqa: E501

        :return: The institutions of this InstitutionsGetResponse.  # noqa: E501
        :rtype: list[Institution]
        """
        return self._institutions

    @institutions.setter
    def institutions(self, institutions):
        """Sets the institutions of this InstitutionsGetResponse.

        A list of Plaid Institution  # noqa: E501

        :param institutions: The institutions of this InstitutionsGetResponse.  # noqa: E501
        :type institutions: list[Institution]
        """

        self._institutions = institutions

    @property
    def total(self):
        """Gets the total of this InstitutionsGetResponse.  # noqa: E501

        The number of institutions returned  # noqa: E501

        :return: The total of this InstitutionsGetResponse.  # noqa: E501
        :rtype: int
        """
        return self._total

    @total.setter
    def total(self, total):
        """Sets the total of this InstitutionsGetResponse.

        The number of institutions returned  # noqa: E501

        :param total: The total of this InstitutionsGetResponse.  # noqa: E501
        :type total: int
        """

        self._total = total

    @property
    def request_id(self):
        """Gets the request_id of this InstitutionsGetResponse.  # noqa: E501

        A unique identifier for the request, which can be used for troubleshooting. This identifier, like all Plaid identifiers, is case sensitive.  # noqa: E501

        :return: The request_id of this InstitutionsGetResponse.  # noqa: E501
        :rtype: str
        """
        return self._request_id

    @request_id.setter
    def request_id(self, request_id):
        """Sets the request_id of this InstitutionsGetResponse.

        A unique identifier for the request, which can be used for troubleshooting. This identifier, like all Plaid identifiers, is case sensitive.  # noqa: E501

        :param request_id: The request_id of this InstitutionsGetResponse.  # noqa: E501
        :type request_id: str
        """

        self._request_id = request_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, InstitutionsGetResponse):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, InstitutionsGetResponse):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    The Plaid API

    The Plaid REST API. Please see https://plaid.com/docs/api for more details.  # noqa: E501
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from plaid.generated_plaid.configuration import Configuration


class BankTransferCreateRequest(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'client_id': 'str',
        'secret': 'str',
        'idempotency_key': 'str',
        'access_token': 'str',
        'account_id': 'str',
        'type': 'BankTransferType',
        'network': 'BankTransferNetwork',
        'amount': 'str',
        'iso_currency_code': 'str',
        'description': 'str',
        'ach_class': 'ACHClass',
        'user': 'BankTransferUser',
        'custom_tag': 'str',
        'metadata': 'dict(str, str)',
        'origination_account_id': 'str'
    }

    attribute_map = {
        'client_id': 'client_id',
        'secret': 'secret',
        'idempotency_key': 'idempotency_key',
        'access_token': 'access_token',
        'account_id': 'account_id',
        'type': 'type',
        'network': 'network',
        'amount': 'amount',
        'iso_currency_code': 'iso_currency_code',
        'description': 'description',
        'ach_class': 'ach_class',
        'user': 'user',
        'custom_tag': 'custom_tag',
        'metadata': 'metadata',
        'origination_account_id': 'origination_account_id'
    }

    def __init__(self, client_id=None, secret=None, idempotency_key=None, access_token=None, account_id=None, type=None, network=None, amount=None, iso_currency_code=None, description=None, ach_class=None, user=None, custom_tag=None, metadata=None, origination_account_id=None, local_vars_configuration=None):  # noqa: E501
        """BankTransferCreateRequest - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._client_id = None
        self._secret = None
        self._idempotency_key = None
        self._access_token = None
        self._account_id = None
        self._type = None
        self._network = None
        self._amount = None
        self._iso_currency_code = None
        self._description = None
        self._ach_class = None
        self._user = None
        self._custom_tag = None
        self._metadata = None
        self._origination_account_id = None
        self.discriminator = None

        self.client_id = client_id
        self.secret = secret
        self.idempotency_key = idempotency_key
        self.access_token = access_token
        self.account_id = account_id
        self.type = type
        self.network = network
        self.amount = amount
        self.iso_currency_code = iso_currency_code
        self.description = description
        if ach_class is not None:
            self.ach_class = ach_class
        self.user = user
        if custom_tag is not None:
            self.custom_tag = custom_tag
        self.metadata = metadata
        if origination_account_id is not None:
            self.origination_account_id = origination_account_id

    @property
    def client_id(self):
        """Gets the client_id of this BankTransferCreateRequest.  # noqa: E501

        Your Plaid API `client_id`.  # noqa: E501

        :return: The client_id of this BankTransferCreateRequest.  # noqa: E501
        :rtype: str
        """
        return self._client_id

    @client_id.setter
    def client_id(self, client_id):
        """Sets the client_id of this BankTransferCreateRequest.

        Your Plaid API `client_id`.  # noqa: E501

        :param client_id: The client_id of this BankTransferCreateRequest.  # noqa: E501
        :type client_id: str
        """
        if self.local_vars_configuration.client_side_validation and client_id is None:  # noqa: E501
            raise ValueError("Invalid value for `client_id`, must not be `None`")  # noqa: E501

        self._client_id = client_id

    @property
    def secret(self):
        """Gets the secret of this BankTransferCreateRequest.  # noqa: E501

        Your Plaid API `secret`.  # noqa: E501

        :return: The secret of this BankTransferCreateRequest.  # noqa: E501
        :rtype: str
        """
        return self._secret

    @secret.setter
    def secret(self, secret):
        """Sets the secret of this BankTransferCreateRequest.

        Your Plaid API `secret`.  # noqa: E501

        :param secret: The secret of this BankTransferCreateRequest.  # noqa: E501
        :type secret: str
        """
        if self.local_vars_configuration.client_side_validation and secret is None:  # noqa: E501
            raise ValueError("Invalid value for `secret`, must not be `None`")  # noqa: E501

        self._secret = secret

    @property
    def idempotency_key(self):
        """Gets the idempotency_key of this BankTransferCreateRequest.  # noqa: E501

        A random key provided by the client, per unique bank transfer. Maximum of 50 characters.  The API supports idempotency for safely retrying requests without accidentally performing the same operation twice. For example, if a request to create a bank transfer fails due to a network connection error, you can retry the request with the same idempotency key to guarantee that only a single bank transfer is created.  # noqa: E501

        :return: The idempotency_key of this BankTransferCreateRequest.  # noqa: E501
        :rtype: str
        """
        return self._idempotency_key

    @idempotency_key.setter
    def idempotency_key(self, idempotency_key):
        """Sets the idempotency_key of this BankTransferCreateRequest.

        A random key provided by the client, per unique bank transfer. Maximum of 50 characters.  The API supports idempotency for safely retrying requests without accidentally performing the same operation twice. For example, if a request to create a bank transfer fails due to a network connection error, you can retry the request with the same idempotency key to guarantee that only a single bank transfer is created.  # noqa: E501

        :param idempotency_key: The idempotency_key of this BankTransferCreateRequest.  # noqa: E501
        :type idempotency_key: str
        """
        if self.local_vars_configuration.client_side_validation and idempotency_key is None:  # noqa: E501
            raise ValueError("Invalid value for `idempotency_key`, must not be `None`")  # noqa: E501

        self._idempotency_key = idempotency_key

    @property
    def access_token(self):
        """Gets the access_token of this BankTransferCreateRequest.  # noqa: E501

        The Plaid `access_token` for the account that will be debited or credited.  # noqa: E501

        :return: The access_token of this BankTransferCreateRequest.  # noqa: E501
        :rtype: str
        """
        return self._access_token

    @access_token.setter
    def access_token(self, access_token):
        """Sets the access_token of this BankTransferCreateRequest.

        The Plaid `access_token` for the account that will be debited or credited.  # noqa: E501

        :param access_token: The access_token of this BankTransferCreateRequest.  # noqa: E501
        :type access_token: str
        """
        if self.local_vars_configuration.client_side_validation and access_token is None:  # noqa: E501
            raise ValueError("Invalid value for `access_token`, must not be `None`")  # noqa: E501

        self._access_token = access_token

    @property
    def account_id(self):
        """Gets the account_id of this BankTransferCreateRequest.  # noqa: E501

        The Plaid `account_id` for the account that will be debited or credited.  # noqa: E501

        :return: The account_id of this BankTransferCreateRequest.  # noqa: E501
        :rtype: str
        """
        return self._account_id

    @account_id.setter
    def account_id(self, account_id):
        """Sets the account_id of this BankTransferCreateRequest.

        The Plaid `account_id` for the account that will be debited or credited.  # noqa: E501

        :param account_id: The account_id of this BankTransferCreateRequest.  # noqa: E501
        :type account_id: str
        """
        if self.local_vars_configuration.client_side_validation and account_id is None:  # noqa: E501
            raise ValueError("Invalid value for `account_id`, must not be `None`")  # noqa: E501

        self._account_id = account_id

    @property
    def type(self):
        """Gets the type of this BankTransferCreateRequest.  # noqa: E501


        :return: The type of this BankTransferCreateRequest.  # noqa: E501
        :rtype: BankTransferType
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this BankTransferCreateRequest.


        :param type: The type of this BankTransferCreateRequest.  # noqa: E501
        :type type: BankTransferType
        """
        if self.local_vars_configuration.client_side_validation and type is None:  # noqa: E501
            raise ValueError("Invalid value for `type`, must not be `None`")  # noqa: E501

        self._type = type

    @property
    def network(self):
        """Gets the network of this BankTransferCreateRequest.  # noqa: E501


        :return: The network of this BankTransferCreateRequest.  # noqa: E501
        :rtype: BankTransferNetwork
        """
        return self._network

    @network.setter
    def network(self, network):
        """Sets the network of this BankTransferCreateRequest.


        :param network: The network of this BankTransferCreateRequest.  # noqa: E501
        :type network: BankTransferNetwork
        """
        if self.local_vars_configuration.client_side_validation and network is None:  # noqa: E501
            raise ValueError("Invalid value for `network`, must not be `None`")  # noqa: E501

        self._network = network

    @property
    def amount(self):
        """Gets the amount of this BankTransferCreateRequest.  # noqa: E501

        The transfer amount (decimal string with two digits of precision e.g. \"10.00\").  # noqa: E501

        :return: The amount of this BankTransferCreateRequest.  # noqa: E501
        :rtype: str
        """
        return self._amount

    @amount.setter
    def amount(self, amount):
        """Sets the amount of this BankTransferCreateRequest.

        The transfer amount (decimal string with two digits of precision e.g. \"10.00\").  # noqa: E501

        :param amount: The amount of this BankTransferCreateRequest.  # noqa: E501
        :type amount: str
        """
        if self.local_vars_configuration.client_side_validation and amount is None:  # noqa: E501
            raise ValueError("Invalid value for `amount`, must not be `None`")  # noqa: E501

        self._amount = amount

    @property
    def iso_currency_code(self):
        """Gets the iso_currency_code of this BankTransferCreateRequest.  # noqa: E501

        The currency of the transfer amount – should be set to \"USD\".  # noqa: E501

        :return: The iso_currency_code of this BankTransferCreateRequest.  # noqa: E501
        :rtype: str
        """
        return self._iso_currency_code

    @iso_currency_code.setter
    def iso_currency_code(self, iso_currency_code):
        """Sets the iso_currency_code of this BankTransferCreateRequest.

        The currency of the transfer amount – should be set to \"USD\".  # noqa: E501

        :param iso_currency_code: The iso_currency_code of this BankTransferCreateRequest.  # noqa: E501
        :type iso_currency_code: str
        """
        if self.local_vars_configuration.client_side_validation and iso_currency_code is None:  # noqa: E501
            raise ValueError("Invalid value for `iso_currency_code`, must not be `None`")  # noqa: E501

        self._iso_currency_code = iso_currency_code

    @property
    def description(self):
        """Gets the description of this BankTransferCreateRequest.  # noqa: E501

        The transfer description. Maximum of 8 characters.  # noqa: E501

        :return: The description of this BankTransferCreateRequest.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this BankTransferCreateRequest.

        The transfer description. Maximum of 8 characters.  # noqa: E501

        :param description: The description of this BankTransferCreateRequest.  # noqa: E501
        :type description: str
        """
        if self.local_vars_configuration.client_side_validation and description is None:  # noqa: E501
            raise ValueError("Invalid value for `description`, must not be `None`")  # noqa: E501

        self._description = description

    @property
    def ach_class(self):
        """Gets the ach_class of this BankTransferCreateRequest.  # noqa: E501


        :return: The ach_class of this BankTransferCreateRequest.  # noqa: E501
        :rtype: ACHClass
        """
        return self._ach_class

    @ach_class.setter
    def ach_class(self, ach_class):
        """Sets the ach_class of this BankTransferCreateRequest.


        :param ach_class: The ach_class of this BankTransferCreateRequest.  # noqa: E501
        :type ach_class: ACHClass
        """

        self._ach_class = ach_class

    @property
    def user(self):
        """Gets the user of this BankTransferCreateRequest.  # noqa: E501


        :return: The user of this BankTransferCreateRequest.  # noqa: E501
        :rtype: BankTransferUser
        """
        return self._user

    @user.setter
    def user(self, user):
        """Sets the user of this BankTransferCreateRequest.


        :param user: The user of this BankTransferCreateRequest.  # noqa: E501
        :type user: BankTransferUser
        """
        if self.local_vars_configuration.client_side_validation and user is None:  # noqa: E501
            raise ValueError("Invalid value for `user`, must not be `None`")  # noqa: E501

        self._user = user

    @property
    def custom_tag(self):
        """Gets the custom_tag of this BankTransferCreateRequest.  # noqa: E501

        An arbitrary string provided by the client for storage with the bank transfer. Will be returned in all `BankTransfer` objects. May be up to 100 characters.  # noqa: E501

        :return: The custom_tag of this BankTransferCreateRequest.  # noqa: E501
        :rtype: str
        """
        return self._custom_tag

    @custom_tag.setter
    def custom_tag(self, custom_tag):
        """Sets the custom_tag of this BankTransferCreateRequest.

        An arbitrary string provided by the client for storage with the bank transfer. Will be returned in all `BankTransfer` objects. May be up to 100 characters.  # noqa: E501

        :param custom_tag: The custom_tag of this BankTransferCreateRequest.  # noqa: E501
        :type custom_tag: str
        """

        self._custom_tag = custom_tag

    @property
    def metadata(self):
        """Gets the metadata of this BankTransferCreateRequest.  # noqa: E501

        The Metadata object is a mapping of client-provided String fields to any String value. The following limitations apply: - The JSON values must be Strings (no nested JSON objects allowed) - Only ASCII characters may be used - Maximum of 50 key/value pairs - Maximum key length of 40 characters - Maximum value length of 500 characters   # noqa: E501

        :return: The metadata of this BankTransferCreateRequest.  # noqa: E501
        :rtype: dict(str, str)
        """
        return self._metadata

    @metadata.setter
    def metadata(self, metadata):
        """Sets the metadata of this BankTransferCreateRequest.

        The Metadata object is a mapping of client-provided String fields to any String value. The following limitations apply: - The JSON values must be Strings (no nested JSON objects allowed) - Only ASCII characters may be used - Maximum of 50 key/value pairs - Maximum key length of 40 characters - Maximum value length of 500 characters   # noqa: E501

        :param metadata: The metadata of this BankTransferCreateRequest.  # noqa: E501
        :type metadata: dict(str, str)
        """

        self._metadata = metadata

    @property
    def origination_account_id(self):
        """Gets the origination_account_id of this BankTransferCreateRequest.  # noqa: E501

        Plaid’s unique identifier for the origination account for this transfer. If you have more than one origination account, this value must be specified.  # noqa: E501

        :return: The origination_account_id of this BankTransferCreateRequest.  # noqa: E501
        :rtype: str
        """
        return self._origination_account_id

    @origination_account_id.setter
    def origination_account_id(self, origination_account_id):
        """Sets the origination_account_id of this BankTransferCreateRequest.

        Plaid’s unique identifier for the origination account for this transfer. If you have more than one origination account, this value must be specified.  # noqa: E501

        :param origination_account_id: The origination_account_id of this BankTransferCreateRequest.  # noqa: E501
        :type origination_account_id: str
        """

        self._origination_account_id = origination_account_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BankTransferCreateRequest):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, BankTransferCreateRequest):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    The Plaid API

    The Plaid REST API. Please see https://plaid.com/docs/api for more details.  # noqa: E501
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from plaid.generated_plaid.configuration import Configuration


class AssetReportUser(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'client_user_id': 'str',
        'first_name': 'str',
        'middle_name': 'str',
        'last_name': 'str',
        'ssn': 'str',
        'phone_number': 'str',
        'email': 'str'
    }

    attribute_map = {
        'client_user_id': 'client_user_id',
        'first_name': 'first_name',
        'middle_name': 'middle_name',
        'last_name': 'last_name',
        'ssn': 'ssn',
        'phone_number': 'phone_number',
        'email': 'email'
    }

    def __init__(self, client_user_id=None, first_name=None, middle_name=None, last_name=None, ssn=None, phone_number=None, email=None, local_vars_configuration=None):  # noqa: E501
        """AssetReportUser - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._client_user_id = None
        self._first_name = None
        self._middle_name = None
        self._last_name = None
        self._ssn = None
        self._phone_number = None
        self._email = None
        self.discriminator = None

        if client_user_id is not None:
            self.client_user_id = client_user_id
        if first_name is not None:
            self.first_name = first_name
        if middle_name is not None:
            self.middle_name = middle_name
        if last_name is not None:
            self.last_name = last_name
        if ssn is not None:
            self.ssn = ssn
        if phone_number is not None:
            self.phone_number = phone_number
        if email is not None:
            self.email = email

    @property
    def client_user_id(self):
        """Gets the client_user_id of this AssetReportUser.  # noqa: E501

        An identifier you determine and submit for the user.  # noqa: E501

        :return: The client_user_id of this AssetReportUser.  # noqa: E501
        :rtype: str
        """
        return self._client_user_id

    @client_user_id.setter
    def client_user_id(self, client_user_id):
        """Sets the client_user_id of this AssetReportUser.

        An identifier you determine and submit for the user.  # noqa: E501

        :param client_user_id: The client_user_id of this AssetReportUser.  # noqa: E501
        :type client_user_id: str
        """

        self._client_user_id = client_user_id

    @property
    def first_name(self):
        """Gets the first_name of this AssetReportUser.  # noqa: E501

        The user's first name. Required for the Fannie Mae Day 1 Certainty™ program.  # noqa: E501

        :return: The first_name of this AssetReportUser.  # noqa: E501
        :rtype: str
        """
        return self._first_name

    @first_name.setter
    def first_name(self, first_name):
        """Sets the first_name of this AssetReportUser.

        The user's first name. Required for the Fannie Mae Day 1 Certainty™ program.  # noqa: E501

        :param first_name: The first_name of this AssetReportUser.  # noqa: E501
        :type first_name: str
        """

        self._first_name = first_name

    @property
    def middle_name(self):
        """Gets the middle_name of this AssetReportUser.  # noqa: E501

        The user's middle name  # noqa: E501

        :return: The middle_name of this AssetReportUser.  # noqa: E501
        :rtype: str
        """
        return self._middle_name

    @middle_name.setter
    def middle_name(self, middle_name):
        """Sets the middle_name of this AssetReportUser.

        The user's middle name  # noqa: E501

        :param middle_name: The middle_name of this AssetReportUser.  # noqa: E501
        :type middle_name: str
        """

        self._middle_name = middle_name

    @property
    def last_name(self):
        """Gets the last_name of this AssetReportUser.  # noqa: E501

        The user's last name.  Required for the Fannie Mae Day 1 Certainty™ program.  # noqa: E501

        :return: The last_name of this AssetReportUser.  # noqa: E501
        :rtype: str
        """
        return self._last_name

    @last_name.setter
    def last_name(self, last_name):
        """Sets the last_name of this AssetReportUser.

        The user's last name.  Required for the Fannie Mae Day 1 Certainty™ program.  # noqa: E501

        :param last_name: The last_name of this AssetReportUser.  # noqa: E501
        :type last_name: str
        """

        self._last_name = last_name

    @property
    def ssn(self):
        """Gets the ssn of this AssetReportUser.  # noqa: E501

        The user's Social Security Number. Required for the Fannie Mae Day 1 Certainty™ program.  Format: \"ddd-dd-dddd\"  # noqa: E501

        :return: The ssn of this AssetReportUser.  # noqa: E501
        :rtype: str
        """
        return self._ssn

    @ssn.setter
    def ssn(self, ssn):
        """Sets the ssn of this AssetReportUser.

        The user's Social Security Number. Required for the Fannie Mae Day 1 Certainty™ program.  Format: \"ddd-dd-dddd\"  # noqa: E501

        :param ssn: The ssn of this AssetReportUser.  # noqa: E501
        :type ssn: str
        """

        self._ssn = ssn

    @property
    def phone_number(self):
        """Gets the phone_number of this AssetReportUser.  # noqa: E501

        The user's phone number, in E.164 format: +{countrycode}{number}. For example: \"+14151234567\"  # noqa: E501

        :return: The phone_number of this AssetReportUser.  # noqa: E501
        :rtype: str
        """
        return self._phone_number

    @phone_number.setter
    def phone_number(self, phone_number):
        """Sets the phone_number of this AssetReportUser.

        The user's phone number, in E.164 format: +{countrycode}{number}. For example: \"+14151234567\"  # noqa: E501

        :param phone_number: The phone_number of this AssetReportUser.  # noqa: E501
        :type phone_number: str
        """

        self._phone_number = phone_number

    @property
    def email(self):
        """Gets the email of this AssetReportUser.  # noqa: E501

        The user's email address.  # noqa: E501

        :return: The email of this AssetReportUser.  # noqa: E501
        :rtype: str
        """
        return self._email

    @email.setter
    def email(self, email):
        """Sets the email of this AssetReportUser.

        The user's email address.  # noqa: E501

        :param email: The email of this AssetReportUser.  # noqa: E501
        :type email: str
        """

        self._email = email

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AssetReportUser):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, AssetReportUser):
            return True

        return self.to_dict() != other.to_dict()



from __future__ import absolute_import

# flake8: noqa

# import apis into api package
from plaid.generated_plaid.api.default_api import DefaultApi
from plaid.generated_plaid.api.plaid_api import PlaidApi
